#include "getref.h"

/* GLOBAL.H -- Global variables used by getref 
 *
 * The global variables defined in this file control much of the operation
 * of getref. They describe the significant names of the database tables
 * and fields used by getref as well as the corresponding names of the
 * header keyword fields. If new instruments or reference files are added 
 * to the calibration pipeline, this file must be updated to track the 
 * changes. The variables in this file are structured as arrays of pointers
 * to character strings. The dimensions of the arrays are defined by macros 
 * in getref.h. Each array must be terminated by a zero length string so 
 * that the program using the array knows where it ends.
 *
 * The INST_CDBS and INST_DADS arrays contain the names of the instruments 
 * in alphabetical order. This order is the same (and must remain the same) 
 * as the instruments and icodes macros defined in config.h. All other arrays 
 * in this file subscripted on instrument must also have the same number of
 * elements in the same order as these arrays. The INST_CDBS array contains 
 * the names of the instruments as stored in the cdbs_mode table and the
 * INST_DADS array contains the names of the instruments as stored in 
 * various otfc tables. 
 *
 * The INST_ABBREV array contains three letter abbreviations for the
 * instrument names used in the otfc database tables.
 *
 * The IS_FITS array indicated wheteher files associated with this 
 * instrument are all in fits format.
 *
 * The CDBSFILE array contains the name of the file level relation for
 * each instrument in the cdbs database. The CDBSROW array contains the name
 * of the corresponding row level relation and the DADSTAB array contains 
 * the name of the corresponding relation in the dads database. The OBSFIELD
 * array contains the name of the field in the dads relation containing the
 * name of the observation set name. The LOCKFIELD contains the name of the
 * field in the dads relation
 *
 * The DETAIL_FILECOL array contains the fields in the cdbs file level 
 * relation used in the detail query. The DETAIL_ROWCOL array contains the
 * names of the fields in the cdbs row level relation, aside from the 
 * observation mode fields, which are used in the detail query.
 *
 * History:
 * 04/20/06  xxxxx  MSwam   remove unused otfc fields
 */

char *inst_cdbs[MAXINST] = {"acs", "foc", "fos", "hrs", "hsp", "nic",
"stis", "synphot", "wfpc2", "wfpc", "", "", "", "", ""};

char *inst_dads[MAXINST] = {"acs", "foc", "fos", "hrs", "hsp", "nicmos",
"stis", "synphot", "wfpc2", "wfpc", "", "", "", "", ""};


int is_fits[MAXINST] = {YES, NO, NO,  NO, NO, YES, YES, NO, NO, NO, 
NO, NO, NO, NO, ERR};

char *cdbsfile[MAXINST] ={"acs_file", "foc_file", "fos_file", "hrs_file",
"hsp_file", "nic_file", "stis_file", "synphot_file", "wfpc2_file",
"wfpc_file", "", "", "", "", ""};

char *cdbsrow[MAXINST] ={"acs_row", "foc_row", "fos_row", "hrs_row", 
"hsp_row", "nic_row", "stis_row", "synphot_row", "wfpc2_row", 
"wfpc_row", "", "", "", "", ""};

char *dadstab[MAXINST] = {"acs_ref_data", "foc_ref_data", "fos_ref_data",
"hrs_ref_data", "hsp_ref_data", "nicmos_ref_data", "stis_ref_data",
"?", "wfpc2_ref_data", "wfpc_ref_data", "", "", "", "", ""};

char *obsfield[MAXINST] = {"asr_data_set_name", "fcr_data_set_name", 
"fsr_data_set_name", "hsr_data_set_name", "hpr_data_set_name", 
"nsr_data_set_name", "ssr_data_set_name", "?", "w2r_data_set_name", 
"wcr_data_set_name", "", "", "", "", ""};

/*
 * Complete set of lock fields for future reference
 *
 * char *lockfield[MAXINST] = {"acr_otfc_lock", "fcr_otfc_lock", 
 * "fsr_otfc_lock", "hsr_otfc_lock", "hpr_otfc_lock", "nsr_otfc_lock", 
 * "ssr_otfc_lock", "?", "w2r_otfc_lock", "wcr_otfc_lock", 
 * "?", "?", "?", "?", "?"};
 */

char *lockfield[MAXINST] = {"?", "?", "?", "?", "?", "?", 
"?", "?", "?", "?", "?", "?", "?", "?", ""};

char *detail_filecol[MAXDETAIL] = {"file_name", "reference_file_type",
"useafter_date", "general_availability_date", "opus_load_date", 
"archive_date", "reject_flag", "comparison_file_name", "", ""};

char *detail_rowcol[MAXDETAIL] = {"pedigree", "observation_begin_date", 
"observation_end_date", "", "", "", "", "" "", ""};

